# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.0.0-v202409011703-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class GraphQLInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query': 'str',
        'variables': 'dict(str, object)'
    }

    attribute_map = {
        'query': 'query',
        'variables': 'variables'
    }

    def __init__(self, query=None, variables=None):
        """
        GraphQLInputV1 - a model defined in Swagger
        """

        self._query = None
        self._variables = None

        if query is not None:
          self.query = query
        if variables is not None:
          self.variables = variables

    @property
    def query(self):
        """
        Gets the query of this GraphQLInputV1.
        GraphQL query

        :return: The query of this GraphQLInputV1.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this GraphQLInputV1.
        GraphQL query

        :param query: The query of this GraphQLInputV1.
        :type: str
        """

        self._query = query

    @property
    def variables(self):
        """
        Gets the variables of this GraphQLInputV1.
        Variable substitutions for the query

        :return: The variables of this GraphQLInputV1.
        :rtype: dict(str, object)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this GraphQLInputV1.
        Variable substitutions for the query

        :param variables: The variables of this GraphQLInputV1.
        :type: dict(str, object)
        """

        self._variables = variables

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GraphQLInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
